Struct suppaftp::list::File

source ·
pub struct File { /* private fields */ }
Describes a file entry on the remote system. This data type is returned in a collection after parsing a LIST output

Implementations

source

impl File

source

pub fn name(&self) -> &str

Get file name

source

pub fn is_directory(&self) -> bool

Get whether file is a directory

source

pub fn is_file(&self) -> bool

Get whether file is a file

Get whether file is a symlink

Returns, if available, the file the symlink is pointing to

source

pub fn size(&self) -> usize

Returned file size in bytes

source

pub fn modified(&self) -> SystemTime

source

pub fn uid(&self) -> Option<u32>

Returns when available the owner user of the file. (POSIX only)

source

pub fn gid(&self) -> Option<u32>

Returns when available the owner group of the file. (POSIX only)

source

pub fn can_read(&self, who: PosixPexQuery) -> bool

Returns whether who can read file

source

pub fn can_write(&self, who: PosixPexQuery) -> bool

Returns whether who can write file

source

pub fn can_execute(&self, who: PosixPexQuery) -> bool

Returns whether who can execute file

source

pub fn from_mlsx_line(line: &str) -> Result<Self, ParseError>

Parse an output line from a MLSD or MLST command

source

pub fn from_posix_line(line: &str) -> Result<Self, ParseError>

Parse a POSIX LIST output line and if it is valid, return a File instance. In case of error a ParseError is returned

source

pub fn from_dos_line(line: &str) -> Result<Self, ParseError>

Try to parse a “LIST” output command line in DOS format. Returns error if syntax is not DOS compliant. DOS syntax has the following syntax:

{DATE} {TIME} {<DIR> | SIZE} {FILENAME}
10-19-20  03:19PM <DIR> pub
04-08-14  03:09PM 403   readme.txt